@@ -50,8 +50,6 @@ class Package(object):
     @property
     def name(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.name
             u'yarg'
@@ -61,8 +59,6 @@ class Package(object):
     @property
     def pypi_url(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.url
             u'https://pypi.python.org/pypi/yarg'
@@ -72,8 +68,6 @@ class Package(object):
     @property
     def summary(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.summary
             u'Some random summary stuff'
@@ -83,19 +77,15 @@ class Package(object):
     @property
     def description(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.description
-            u'A super long description, usually upload from the README'
+            u'A super long description, usually uploaded from the README'
         """
         return self._package['description']
 
     @property
     def homepage(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.homepage
             u'https://kura.io/yarg/'
@@ -108,8 +98,6 @@ class Package(object):
     @property
     def bugtracker(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.bugtracker
             u'https://github.com/kura/yarg/issues'
@@ -122,8 +110,6 @@ class Package(object):
     @property
     def docs(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.docs
             u'https://yarg.readthedocs.org/en/latest'
@@ -136,8 +122,6 @@ class Package(object):
     @property
     def author(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.author
             Author(name=u'Kura', email=u'kura@kura.io')
@@ -149,8 +133,6 @@ class Package(object):
     @property
     def maintainer(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.maintainer
             Maintainer(name=u'Kura', email=u'kura@kura.io')
@@ -162,8 +144,6 @@ class Package(object):
     @property
     def license(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.license
             u'MIT'
@@ -173,8 +153,6 @@ class Package(object):
     @property
     def license_from_classifiers(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.license_from_classifiers
             u'MIT License'
@@ -187,8 +165,6 @@ class Package(object):
     @property
     def downloads(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.downloads
             Downloads(day=50100, week=367941, month=1601938)  # I wish
@@ -202,8 +178,6 @@ class Package(object):
     @property
     def classifiers(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.classifiers
             [u'License :: OSI Approved :: MIT License',
@@ -218,8 +192,6 @@ class Package(object):
         Returns a list of Python version strings that
         the package has listed in :attr:`yarg.Release.classifiers`.
 
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.python_versions
             [u'2.6', u'2.7', u'3.3', u'3.4']
@@ -234,8 +206,6 @@ class Package(object):
         Returns a list of Python implementation strings that
         the package has listed in :attr:`yarg.Release.classifiers`.
 
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.python_implementations
             [u'CPython', u'PyPy']
@@ -246,17 +216,12 @@ class Package(object):
     @property
     def latest_release_id(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.latest_release_id
             u'0.1.0'
         """
         releases = self.release_ids
-        if len(releases) == 1:
-            return releases[0]
-        else:
-            return releases[-1]
+        return self._package['version']
 
     @property
     def latest_release(self):
@@ -264,8 +229,6 @@ class Package(object):
         A list of :class:`yarg.release.Release` objects for each file in the
         latest release.
 
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.latest_release
             [<Release 0.1.0>, <Release 0.1.0>]
@@ -280,8 +243,6 @@ class Package(object):
         in the latest set of release files is `wheel` format. Returns
         `False` if not.
 
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.has_wheel
             True
@@ -298,8 +259,6 @@ class Package(object):
         in the latest set of release files is `egg` format. Returns
         `False` if not.
 
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.has_egg
             False
@@ -316,8 +275,6 @@ class Package(object):
         in the latest set of release files is `source` format. Returns
         `False` if not.
 
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.has_source
             True
@@ -330,14 +287,13 @@ class Package(object):
     @property
     def release_ids(self):
         """
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> package.release_ids
             [u'0.0.1', u'0.0.5', u'0.1.0']
         """
-        r = [k for k in self._releases.keys() if len(self._releases[k]) > 0]
-        return sorted(r)
+        r = [(k, self._releases[k][0]['upload_time']) for k in self._releases.keys()
+                                                   if len(self._releases[k]) > 0]
+        return [k[0] for k in sorted(r, key=lambda k: k[1])]
 
     def release(self, release_id):
         """
@@ -346,8 +302,6 @@ class Package(object):
 
         :param release_id: A pypi release id.
 
-        Usage:
-
             >>> package = yarg.get('yarg')
             >>> last_release = yarg.releases[-1]
             >>> package.release(last_release)
